@@ -14,8 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pdb
-
 import logging as mod_logging
 import math as mod_math
 
@@ -347,7 +345,7 @@ class LocationDelta:
         """
         Version 1:
             Distance (in meters).
-            angle_from_north *clockwise*. 
+            angle_from_north *clockwise*.
             ...must be given
         Version 2:
             latitude_diff and longitude_diff
@@ -362,8 +360,8 @@ class LocationDelta:
         elif (latitude_diff is not None) and (longitude_diff is not None):
             if (distance is not None) or (angle is not None):
                 raise Exception('No distance/angle if using lat/lon diff!')
-            this.latitude_diff  = latitude_diff
-            this.longitude_diff = longitude_diff
+            self.latitude_diff  = latitude_diff
+            self.longitude_diff = longitude_diff
             self.move_function = self.move_by_lat_lon_diff
 
     def move(self, location):
