@@ -15,36 +15,36 @@
 # limitations under the License.
 
 import sys as mod_sys
+import math as mod_math
 import xml.sax.saxutils as mod_saxutils
 
 PYTHON_VERSION = mod_sys.version.split(' ')[0]
 
+
 def to_xml(tag, attributes=None, content=None, default=None, escape=False):
     attributes = attributes or {}
     result = '\n<%s' % tag
 
-    if not content and default:
+    if content is None and default:
         content = default
 
     if attributes:
         for attribute in attributes.keys():
-            result += ' %s="%s"' % (attribute, attributes[attribute])
-    if content:
-        if escape:
-            result += '>%s</%s>' % (mod_saxutils.escape(content), tag)
-        else:
-            result += '>%s</%s>' % (content, tag)
-    elif content == '':
-        result += '></%s>' % tag
-    else:
-        result += '/>'
+            result += make_str(' %s="%s"' % (attribute, attributes[attribute]))
 
-    result += ''
+    if content is None:
+        result += '/>'
+    else:
+        if escape:
+            result += make_str('>%s</%s>' % (mod_saxutils.escape(content), tag))
+        else:
+            result += make_str('>%s</%s>' % (content, tag))
 
     result = make_str(result)
-	
+
     return result
 
+
 def is_numeric(object):
     try:
         float(object)
@@ -54,9 +54,13 @@ def is_numeric(object):
     except ValueError:
         return False
 
-def to_number(s, default=0):
+
+def to_number(s, default=0, nan_value=None):
     try:
-        return float(s)
+        result = float(s)
+        if mod_math.isnan(result):
+            return nan_value
+        return result
     except TypeError:
         pass
     except ValueError:
@@ -64,8 +68,15 @@ def to_number(s, default=0):
     return default
 
 
+def total_seconds(timedelta):
+    """ Some versions of python dont have timedelta.total_seconds() method. """
+    if timedelta is None:
+        return None
+    return (timedelta.days * 86400) + timedelta.seconds
+
 # Hash utilities:
 
+
 def __hash(obj):
     result = 0
 
@@ -78,6 +89,7 @@ def __hash(obj):
 
     return hash(obj)
 
+
 def hash_list_or_tuple(iteration):
     result = 17
 
@@ -86,12 +98,13 @@ def hash_list_or_tuple(iteration):
 
     return result
 
-def hash_object(obj, *attributes):
+
+def hash_object(obj, attributes):
     result = 19
 
     for attribute in attributes:
         result = result * 31 + __hash(getattr(obj, attribute))
-	
+
     return result
 
 
